@@ -1,6 +1,6 @@
 /*
  *  ScanGear MP for Linux
- *  Copyright CANON INC. 2007-2021
+ *  Copyright CANON INC. 2007-2024
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,9 +30,9 @@
 /* N_ macro */
 #include "support.h"
 
-#define	STR_CNMS_LS_007_VER_NUM		"4.30"
+#define	STR_CNMS_LS_007_VER_NUM		"4.90"
 #define	STR_CNMS_LS_007_YEAR_BEGIN	"2007"
-#define	STR_CNMS_LS_007_YEAR_END	"2021"
+#define	STR_CNMS_LS_007_YEAR_END	"2025"
 
 /*STR_CNMS_LS_001_01*/
 #define	STR_CNMS_LS_001_01	N_( "Scanner" )
@@ -94,6 +94,8 @@
 #define	STR_CNMS_LS_005_12	N_( "A4" )
 /*STR_CNMS_LS_005_13*/
 #define	STR_CNMS_LS_005_13	N_( "Letter" )
+/*STR_CNMS_LS_005_14*/
+#define	STR_CNMS_LS_005_14	N_( "Statement" )
 
 #define	STR_CNMS_LS_007_01		"ScanGear"
 #define	STR_CNMS_LS_007_02		"ScanGear MP"
