@@ -1,6 +1,6 @@
 /*
  *  ScanGear MP for Linux
- *  Copyright CANON INC. 2007-2021
+ *  Copyright CANON INC. 2007-2024
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -89,6 +89,22 @@ static CIJSC_MAINUI_ITEM_TABLE size_platen_table[] = {
 	{ -1,						NULL, },
 };
 
+/* size(Platen A5) : A4 Letter B5 2L_L not support*/
+static CIJSC_MAINUI_ITEM_TABLE size_platen_A5_table[] = {
+	{ CIJSC_SIZE_CARD,			STR_CNMS_LS_005_01, },
+	{ CIJSC_SIZE_L_L,			STR_CNMS_LS_005_02, },
+	{ CIJSC_SIZE_L_P,			STR_CNMS_LS_005_03, },
+	{ CIJSC_SIZE_4X6_L,			STR_CNMS_LS_005_04, },
+	{ CIJSC_SIZE_4X6_P,			STR_CNMS_LS_005_05, },
+	{ CIJSC_SIZE_HAGAKI_L,		STR_CNMS_LS_005_06, },
+	{ CIJSC_SIZE_HAGAKI_P,		STR_CNMS_LS_005_07, },
+	{ CIJSC_SIZE_2L_P,			STR_CNMS_LS_005_09, },
+	{ CIJSC_SIZE_A5,			STR_CNMS_LS_005_10, },
+	{ CIJSC_SIZE_STATEMENT,		STR_CNMS_LS_005_14, },
+	{ -1,						NULL, },
+};
+
+
 /* size(ADF) */
 static CIJSC_MAINUI_ITEM_TABLE size_adf_table[] = {
 	{ CIJSC_SIZE_A4,			STR_CNMS_LS_005_12, },
@@ -226,6 +242,22 @@ static int ui_main_combobox_set_id( SGMP_Data *data, GtkWidget *combo, CIJSC_MAI
 	return 0;
 }
 
+static CIJSC_MAINUI_ITEM_TABLE *get_size_table ( SGMP_Data *data )
+{
+	CIJSC_MAINUI_ITEM_TABLE *size_table = size_platen_table;
+    int current_scanmode ;
+	current_scanmode = ui_main_combobox_get_id( data, data->combobox_scanmode, (CIJSC_MAINUI_ITEM_TABLE *)scanmode_table );
+	if ( current_scanmode == CIJSC_SCANMODE_PLATEN ) {
+		if ( data->platen_A5) {
+			size_table = size_platen_A5_table;
+		}
+	}
+	else {
+		size_table = size_adf_table;
+	}
+	return size_table;
+}
+
 static void ui_main_combobox_set_default_size( SGMP_Data *data )
 {
 	DBGMSG("->\n");
@@ -237,6 +269,25 @@ static void ui_main_combobox_set_default_size( SGMP_Data *data )
 	}
 }
 
+static void ui_main_combobox_set_default_size_new( SGMP_Data *data )
+{
+	DBGMSG("->\n");
+	int current_scanmode ;
+	current_scanmode = ui_main_combobox_get_id( data, data->combobox_scanmode, (CIJSC_MAINUI_ITEM_TABLE *)scanmode_table );
+	if( data->platen_A5 && current_scanmode == CIJSC_SCANMODE_PLATEN ) {
+		if ( ui_main_is_en_US() ) {
+			ui_main_combobox_set_id( data, data->combobox_size, size_platen_A5_table, CIJSC_SIZE_STATEMENT );
+		}
+	    else {
+			ui_main_combobox_set_id( data, data->combobox_size, size_platen_A5_table, CIJSC_SIZE_A5 );
+	    }
+	}
+	else {
+		ui_main_combobox_set_default_size( data );
+ 
+	}
+}
+
 static void ui_main_button_scan_main( SGMP_Data *data )
 {
 	DBGMSG("->\n");
@@ -245,7 +296,9 @@ static void ui_main_button_scan_main( SGMP_Data *data )
 	data->scan_scanmode = ui_main_combobox_get_id( data, data->combobox_scanmode, (CIJSC_MAINUI_ITEM_TABLE *)scanmode_table );
 	data->scan_source = ui_main_combobox_get_id( data, data->combobox_source, (CIJSC_MAINUI_ITEM_TABLE *)source_table );
 	data->scan_color = ui_main_combobox_get_id( data, data->combobox_colormode, (CIJSC_MAINUI_ITEM_TABLE *)colormode_table );
-	data->scan_size = ui_main_combobox_get_id( data, data->combobox_size, (CIJSC_MAINUI_ITEM_TABLE *)size_platen_table );
+	/* get size table*/
+	CIJSC_MAINUI_ITEM_TABLE *size_table = get_size_table( data );
+	data->scan_size = ui_main_combobox_get_id( data, data->combobox_size, size_table);
 	
 	/* scan and save scanned data. */
 	CIJSC_Scan_And_Save( data );
@@ -263,10 +316,20 @@ void CIJSC_UI_main_show( SGMP_Data	*data, CANON_Device const *dev )
 	data->ignore_combobox_changed = TRUE;
 	ui_main_other_combobox_init( data, data->combobox_source, source_table );
 	ui_main_other_combobox_init( data, data->combobox_colormode, colormode_table );
-	ui_main_other_combobox_init( data, data->combobox_size, size_platen_table );
 	ui_main_combobox_scanmode_init( data, dev );
+
+	/* platen_table_init */
+	if ( CIJSC_GET_PLATEN_A5( dev->type ) ) {
+		data->platen_A5 = 1;
+	}
+	else {
+		data->platen_A5 = 0;
+	}
+	
+	ui_main_other_combobox_init( data, data->combobox_size, get_size_table( data ));
+
 	/* set default size. */
-	ui_main_combobox_set_default_size( data );
+	ui_main_combobox_set_default_size_new( data );
 	/* save current scanmode. */
 	data->prev_scanmode = ui_main_combobox_get_id( data, data->combobox_scanmode, (CIJSC_MAINUI_ITEM_TABLE *)scanmode_table );
 	data->ignore_combobox_changed = FALSE;
@@ -283,6 +346,7 @@ void CIJSC_UI_main_combobox_scanmode_changed( SGMP_Data	*data )
 	GtkTreeIter		iter;
 	gint			select_no, i;
 	gchar			*str;
+	CIJSC_MAINUI_ITEM_TABLE *platen_table ;
 	int				current_scanmode;
 	int				current_size;
 
@@ -292,6 +356,14 @@ void CIJSC_UI_main_combobox_scanmode_changed( SGMP_Data	*data )
 		DBGMSG("scanmode changed : %s -> %s\n", 
 				gettext( scanmode_table[data->prev_scanmode].str ),
 				gettext( scanmode_table[current_scanmode].str ) );
+        
+		/*get platen table*/
+		if ( data->platen_A5 ){
+			platen_table = size_platen_A5_table;
+		}
+		else {
+			platen_table = size_platen_table;
+		}
 		
 		/* update Scan(JPEG) button. */
 		if ( current_scanmode == CIJSC_SCANMODE_PLATEN ) {
@@ -303,7 +375,7 @@ void CIJSC_UI_main_combobox_scanmode_changed( SGMP_Data	*data )
 		if ( data->prev_scanmode == CIJSC_SCANMODE_PLATEN ) {
 			/* PLATEN -> ADF */
 			/* get current size and set current size. */
-			current_size = ui_main_combobox_get_id( data, data->combobox_size, (CIJSC_MAINUI_ITEM_TABLE *)size_platen_table );
+			current_size = ui_main_combobox_get_id( data, data->combobox_size, platen_table );
 			ui_main_other_combobox_init( data, data->combobox_size, size_adf_table );
 			if ( ui_main_combobox_set_id( data, data->combobox_size, (CIJSC_MAINUI_ITEM_TABLE *)size_adf_table, current_size ) ) {
 				/* set default size. */
@@ -315,10 +387,10 @@ void CIJSC_UI_main_combobox_scanmode_changed( SGMP_Data	*data )
 				/* ADF -> PLATEN */
 				/* get current size and set current size. */
 				current_size = ui_main_combobox_get_id( data, data->combobox_size, (CIJSC_MAINUI_ITEM_TABLE *)size_adf_table );
-				ui_main_other_combobox_init( data, data->combobox_size, size_platen_table );
-				if ( ui_main_combobox_set_id( data, data->combobox_size, (CIJSC_MAINUI_ITEM_TABLE *)size_platen_table, current_size ) ) {
+				ui_main_other_combobox_init( data, data->combobox_size, platen_table );
+				if ( ui_main_combobox_set_id( data, data->combobox_size, platen_table, current_size ) ) {
 					/* set default size. */
-					ui_main_combobox_set_default_size( data );
+					ui_main_combobox_set_default_size_new( data );
 				}
 			}
 			/* ADF -> ADF : do nothing. */
