@@ -1,6 +1,6 @@
 /*
  *  ScanGear MP for Linux
- *  Copyright CANON INC. 2007-2021
+ *  Copyright CANON INC. 2007-2024
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -168,6 +168,10 @@ typedef struct
 	int			scan_w;
 	int			scan_h;
 	int			scan_res;
+
+	/* platen type */
+	int			platen_A5;
+
 	/* error */
 	int			last_error_quit;
 }SGMP_Data;
@@ -218,6 +222,7 @@ enum{
 	CIJSC_SIZE_B5,
 	CIJSC_SIZE_A4,
 	CIJSC_SIZE_LETTER,
+	CIJSC_SIZE_STATEMENT,
 };
 
 /* file format */
